summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--4x5/keymaps/colemak_mod_dh/keymap.c12
-rw-r--r--readme.md65
2 files changed, 21 insertions, 56 deletions
diff --git a/readme.md b/readme.md
index 3221da0..e553f85 100644
--- a/readme.md
+++ b/readme.md
@@ -32,49 +32,28 @@ For more information on customizing keymaps, take a look at the primary document
### [Keymaps 4x5](/keyboards/handwired/dactyl_manuform/4x5/keymaps/)
-#### Default
-Simple QWERTY layout with 3 Layers.
-#### Dvorak
-
-### [Keymaps 5x6](/keyboards/handwired/dactyl_manuform/5x6/keymaps/)
-
-#### Default
-Just a copy of the Impstyle keymap. Feel free to adjust it.
-
-#### Impstyle
-A simple QWERTY keymap with 3 Layers. Both sides are connected via serial and the Left ist the master.
-
-### [Keymaps 5x7 aka almost Ergodox](/keyboards/handwired/dactyl_manuform/5x7/keymaps/)
-#### Default
-Keymap of Loligagger from geekhack.
-
-### [Keymaps 6x6](/keyboards/handwired/dactyl_manuform/6x6/keymaps/)
-
-#### Default
-Simple QWERTY layout with 3 Layers.
+#### Colemak MOD DH
+See
+[https://colemakmods.github.io/mod-dh/](https://colemakmods.github.io/mod-dh/)
+for details on the general principle. Adapted for the mini mod.
## Required Hardware
-Apart from diodes and key switches for the keyboard matrix in each half, you
-will need:
+Apart from diodes and key switches for the keyboard matrix in each half, you will need:
* 2 Arduino Pro Micros. You can find these on AliExpress for ≈3.50USD each.
* 2 TRRS sockets and 1 TRRS cable, or 2 TRS sockets and 1 TRS cable
-Alternatively, you can use any sort of cable and socket that has at least 3
-wires. If you want to use I2C to communicate between halves, you will need a
-cable with at least 4 wires and 2x 4.7kΩ pull-up resistors
+Alternatively, you can use any sort of cable and socket that has at least 3 wires. If you want to use I2C to communicate between halves, you will need a cable with at least 4 wires and 2x 4.7kΩ pull-up resistors
## Optional Hardware
A speaker can be hooked-up to either side to the `5` (`C6`) pin and `GND`, and turned on via `AUDIO_ENABLE`.
## Wiring
-The 3 wires of the TRS/TRRS cable need to connect GND, VCC, and digital pin 3 (i.e.
-PD0 on the ATmega32u4) between the two Pro Micros.
+The 3 wires of the TRS/TRRS cable need to connect GND, VCC, and digital pin 3 (i.e. PD0 on the ATmega32u4) between the two Pro Micros.
-Next, wire your key matrix to any of the remaining 17 IO pins of the pro micro
-and modify the `matrix.c` accordingly.
+Next, wire your key matrix to any of the remaining 17 IO pins of the pro micro and modify the `matrix.c` accordingly.
The wiring for serial:
@@ -84,9 +63,7 @@ The wiring for i2c:
![i2c wiring](https://i.imgur.com/Hbzhc6E.png)
-The pull-up resistors may be placed on either half. It is also possible
-to use 4 resistors and have the pull-ups in both halves, but this is
-unnecessary in simple use cases.
+The pull-up resistors may be placed on either half. It is also possible to use 4 resistors and have the pull-ups in both halves, but this is unnecessary in simple use cases.
You can change your configuration between serial and i2c by modifying your `config.h` file.
@@ -122,36 +99,24 @@ If you always plug the usb cable into the right board, add an extra flag to your
### Setting EE_hands to use either hands as master
-If you define `EE_HANDS` in your `config.h`, you will need to set the
-EEPROM for the left and right halves.
+If you define `EE_HANDS` in your `config.h`, you will need to set the EEPROM for the left and right halves.
-The EEPROM is used to store whether the
-half is left handed or right handed. This makes it so that the same firmware
-file will run on both hands instead of having to flash left and right handed
-versions of the firmware to each half. To flash the EEPROM file for the left
-half run:
+The EEPROM is used to store whether the half is left handed or right handed. This makes it so that the same firmware file will run on both hands instead of having to flash left and right handed versions of the firmware to each half. To flash the EEPROM file for the left half run:
```
-make handwired/dactyl_promicro:default:dfu-split-left
-make handwired/dactyl_promicro:default:dfu-split-right
+make handwired/dactyl_manuform/4x5:colemak_mod_dh:avrdude-split-left
```
After you have flashed the EEPROM, you then need to set `EE_HANDS` in your config.h, rebuild the hex files and reflash.
-Note that you need to program both halves, but you have the option of using
-different keymaps for each half. You could program the left half with a QWERTY
-layout and the right half with a Colemak layout using bootmagic's default layout option.
-Then if you connect the left half to a computer by USB the keyboard will use QWERTY and Colemak when the
-right half is connected.
+Note that you need to program both halves, but you have the option of using different keymaps for each half. You could program the left half with a QWERTY layout and the right half with a Colemak layout using bootmagic's default layout option. Then if you connect the left half to a computer by USB the keyboard will use QWERTY and Colemak when the right half is connected.
Notes on Using Pro Micro 3.3V
-----------------------------
-Do update the `F_CPU` parameter in `rules.mk` to `8000000` which reflects
-the frequency on the 3.3V board.
+Do update the `F_CPU` parameter in `rules.mk` to `8000000` which reflects the frequency on the 3.3V board.
-Also, if the slave board is producing weird characters in certain columns,
-update the following line in `matrix.c` to the following:
+Also, if the slave board is producing weird characters in certain columns, update the following line in `matrix.c` to the following:
```
// wait_us(30); // without this wait read unstable value.
diff --git a/4x5/keymaps/colemak_mod_dh/keymap.c b/4x5/keymaps/colemak_mod_dh/keymap.c
index 32b52b9..8dc5ad5 100644
--- a/4x5/keymaps/colemak_mod_dh/keymap.c
+++ b/4x5/keymaps/colemak_mod_dh/keymap.c
@@ -29,7 +29,7 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
/* Raise
* ,----------------------------------, ,----------------------------------,
* | | PgUp | up | PgDn | | | CRTL | ALT | mup | MUTE | VOL+ |
* |------+------+------+------+------| |-------------+------+------+------|
* |S(INS)| left | down | right| F11 | | F12 |mleft |mdown |mright| VOL- |
* |------+------+------+------+------| |------+------+------+------+------|
@@ -46,7 +46,7 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
*/
[_RAISE] = LAYOUT( \
- ____, KC_PGUP, KC_UP, KC_PGDN, ____, KC_RCTL, KC_RALT, KC_MU, KC_MUTE, KC_VOLU, \
+ KC_HOME, KC_PGUP, KC_UP, KC_PGDN, KC_END, KC_RCTL, KC_RALT, KC_MU, KC_MUTE, KC_VOLU, \
S(KC_INSERT), KC_LEFT, KC_DOWN, KC_RIGHT, KC_F11, KC_F12, KC_ML, KC_MD, KC_MR, KC_VOLD, \
KC_F1, KC_F2, KC_F3, KC_F4, KC_F5, KC_F6, KC_F7, KC_F8, KC_F9, KC_F10, \
____, RESET, KC_MB1, KC_MB2, \
@@ -61,7 +61,7 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
* |------+------+------+------+------| |------|------+------+------+------|
* | z | x | c | d | v | | m | h | , | . | ' |
* |------+------+------+-------------, ,-------------+------+------+------,
- * | _ | \ | | - | / |
+ * | _ | / | | - | \ |
* '------+------'--------------------' '--------------------'------+------'
* | ESC | BKSP | TAB | | TAB | SPC | RET |
* | + | + | + | | + | + | + |
@@ -75,9 +75,9 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
KC_Q, KC_W, KC_F, KC_P, KC_B, KC_J, KC_L, KC_U, KC_Y, KC_SCLN, \
KC_A, KC_R, KC_S, KC_T, KC_G, KC_K, KC_N, KC_E, KC_I, KC_O, \
KC_Z, KC_X, KC_C, KC_D, KC_V, KC_M, KC_H, KC_COMM, KC_DOT, KC_QUOT, \
- S(KC_MINS), KC_BSLS, KC_MINS, KC_SLSH, \
- RAI_ESC, CTL_BSPC, LGUI_TAB, LGUI_TAB, ALT_SPC, LOW_ENT, \
- KC_LSFT, KC_GRV, S(KC_GRV), KC_RSFT \
+ S(KC_MINS), KC_SLSH, KC_MINS, KC_BSLS, \
+ RAI_ESC, CTL_BSPC, LGUI_TAB, LGUI_TAB, ALT_SPC, LOW_ENT, \
+ KC_LSFT, KC_GRV, S(KC_GRV), KC_RSFT \
),
/* Lower
@@ -29,7 +29,7 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
/* Raise
* ,----------------------------------, ,----------------------------------,
- * | | PgUp | up | PgDn | | | CRTL | ALT | mup | MUTE | VOL+ |
+ * | HOME | PgUp | up | PgDn | END | | CRTL | ALT | mup | MUTE | VOL+ |
* |------+------+------+------+------| |-------------+------+------+------|
* |S(INS)| left | down | right| F11 | | F12 |mleft |mdown |mright| VOL- |